@@ -3,8 +3,8 @@ import os
 import urllib.parse
 from urllib.request import urlopen
 
-from google.cloud import secretmanager_v1, storage
 import requests
+from google.cloud import secretmanager_v1, storage
 
 LOG = logging.getLogger(__name__)
 
@@ -31,7 +31,7 @@ def geddit(url):
     using appropriate exceptions for the backend specific to the scheme.
 
     """
-    components = urllib.parse.urlsplit(url, scheme='file')
+    components = urllib.parse.urlsplit(url, scheme="file")
     fetch_cb = _SCHEME_MAP.get(components.scheme)
     if fetch_cb is None:
         raise ValueError(f'Unknown URL scheme "{components.scheme}" for URL "{url}"')
@@ -44,8 +44,8 @@ def _fetch_file_url(components):
 
     """
     if not os.path.isabs(components.path):
-        raise ValueError('file:// URL path must be absolute')
-    with open(components.path, 'rb') as fobj:
+        raise ValueError("file:// URL path must be absolute")
+    with open(components.path, "rb") as fobj:
         return fobj.read()
 
 
@@ -65,12 +65,12 @@ def _fetch_secret_manager_url(components):
 
     """
     project_id = components.netloc
-    secret_name = components.path.lstrip('/')
-    version = components.fragment if components.fragment != '' else 'latest'
+    secret_name = components.path.lstrip("/")
+    version = components.fragment if components.fragment != "" else "latest"
 
     # Sanity check that there aren't any path components in the secret name or version.
-    if '/' in secret_name or '/' in version:
-        raise ValueError('Secret Manager URL must have form sm://PROJECT_ID/SECRET#VERSION')
+    if "/" in secret_name or "/" in version:
+        raise ValueError("Secret Manager URL must have form sm://PROJECT_ID/SECRET#VERSION")
 
     client = secretmanager_v1.SecretManagerServiceClient()
     secret_path = client.secret_version_path(project_id, secret_name, version)
@@ -83,10 +83,11 @@ def _fetch_storage_url(components):
 
     """
     bucket = components.netloc
-    blob_path = components.path.lstrip('/')
+    blob_path = components.path.lstrip("/")
 
     client = storage.Client()
-    bucket = client.get_bucket(bucket)
+    # using bucket() over get_bucket() to remove the need for bucket permissions
+    bucket = client.bucket(bucket)
     blob = bucket.get_blob(blob_path)
 
     return blob.download_as_bytes()
@@ -104,9 +105,9 @@ def _fetch_data_url(components):
 
 # A table mapping URL schemes into the corresponding callable for that scheme.
 _SCHEME_MAP = {
-    'file': _fetch_file_url,
-    'gs': _fetch_storage_url,
-    'https': _fetch_https_url,
-    'sm': _fetch_secret_manager_url,
-    'data': _fetch_data_url,
+    "file": _fetch_file_url,
+    "gs": _fetch_storage_url,
+    "https": _fetch_https_url,
+    "sm": _fetch_secret_manager_url,
+    "data": _fetch_data_url,
 }
